# Autogenerated by nbdev

d = { 'settings': { 'branch': 'master',
                'doc_baseurl': '/taash',
                'doc_host': 'https://nasheqlbrm.github.io',
                'git_url': 'https://github.com/nasheqlbrm/taash',
                'lib_path': 'taash'},
  'syms': { 'taash.card': { 'taash.card.Card': ('card.html#card', 'taash/card.py'),
                            'taash.card.Card.__eq__': ('card.html#card.__eq__', 'taash/card.py'),
                            'taash.card.Card.__gt__': ('card.html#card.__gt__', 'taash/card.py'),
                            'taash.card.Card.__init__': ('card.html#card.__init__', 'taash/card.py'),
                            'taash.card.Card.__lt__': ('card.html#card.__lt__', 'taash/card.py'),
                            'taash.card.Card.__str__': ('card.html#card.__str__', 'taash/card.py')},
            'taash.deck': { 'taash.deck.Deck': ('deck.html#deck', 'taash/deck.py'),
                            'taash.deck.Deck.__contains__': ('deck.html#deck.__contains__', 'taash/deck.py'),
                            'taash.deck.Deck.__init__': ('deck.html#deck.__init__', 'taash/deck.py'),
                            'taash.deck.Deck.__len__': ('deck.html#deck.__len__', 'taash/deck.py'),
                            'taash.deck.Deck.__str__': ('deck.html#deck.__str__', 'taash/deck.py'),
                            'taash.deck.Deck.pop': ('deck.html#deck.pop', 'taash/deck.py'),
                            'taash.deck.Deck.remove': ('deck.html#deck.remove', 'taash/deck.py'),
                            'taash.deck.Deck.shuffle': ('deck.html#deck.shuffle', 'taash/deck.py'),
                            'taash.deck.draw_n': ('deck.html#draw_n', 'taash/deck.py')}}}